package cz.muni.fi.pb162.school;

/**
 * Rozhraní Student reprezentuje studenta. Student je 
 * identifikován unikátním indentifikátorem id typu int. 
 * Dalším atributem je jeho jméno.
 *
 * @author Petr Adamek &lt;xadamek2@fi.muni.cz&gt;
 */
public interface Student {
    
    /**
     * Tato metoda vrací jméno studenta.
     *
     * @return jméno studenta
     */
    String getName();
    
    /**
     * Tato metoda vrací identifikátor studenta.
     *
     * @return identifikátor studenta
     */
    int getId();
    
    /**
     * <p>Indikuje, zdali je nějaký objekt stejný jako tento student.
     * Jiný objekt je stejný (ekvivalentní) jako tento student právě
     * tehdy, pokud jde také o studenta a ten má stejný identifikátor 
     * id.</p>
     * 
     * <p>Tato metoda musí samozřejmě splňovat obecný kontrakt metody <a 
     * href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/Object.html#equals(java.lang.Object)">Object.equals</a>.</p>
     *
     * @param obj Porovnávaný objekt
     * @return true, jestli je tento objekt stejný jako argument obj
     */
    boolean equals(Object obj);
    
    
    /**
     * Tato metoda vrací hashovací kód daného objektu. Metoda musí splňovat obecný 
     * kontrakt metody <a 
     * href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/Object.html#hashCode()">Object.hashCode()</a>.
     * 
     * @return hashovací k daného objektu
     */
    int hashCode();
    
}
