package cz.muni.fi.pb162.school;

import java.io.InputStream;
import java.io.OutputStream;

import java.util.Collection;

/**
 * Toto rozhraní reprezentuje katalog studentů. Zároveň 
 * umožňuje katalog uložit do souboru nebo jej ze souboru 
 * naopak načíst.
 *
 * @author Petr Adamek &lt;xadamek2@fi.muni.cz&gt;
 */
public interface StudentCatalog {
    
    /**
     * Tato metoda ze zadaného proudu načte obsah katalogu. Katalog je
     * v proudu (souboru) organizován tak, že na každém řádku je jeden 
     * student, přičemž řádek začíná identifikátorem studenta, pak 
     * následuje mezera a zbytek řádku obsahuje jméno studenta. Data
     * jsou v proudu uložena s kódováním UTF-8. Pořadí řádků v souboru
     * není rozhodující.
     *
     * @param is Vstupní proud, ze kterého se budou číst data.
     * @throws StudentCatalogException pokud dojde k chybě při čtení dat z 
     * proudu nebo má vstupní soubor nesprávný formát.
     */
    void load(InputStream is) throws StudentCatalogException;
    
    /**
     * Tato metoda obsah katalogu uloží do daného výstupního proudu. 
     * Formát proudu je stejný jako u metody load().
     *
     * @param os Výstupní proud, do nějž se má katalog zapsat.
     * @throws StudentCatalogException pokud dojde k chybě při zápisu dat do proudu
     */
    void save(OutputStream os) throws StudentCatalogException;
    
    /**
     * Vrátí studenta s daným id.
     * @param id Identifikátor studenta, kterého má metoda vrátit.
     * @return instanci třídy reprezentující studenta s daným identifikátorem 
     * nebo null, pokud takový student neexistuje.
     */
    Student getStudent(int id);
    
    /**
     * Metoda vytvoří nového studenta s daným jménem. Student bude 
     * mít přidělen nový identifikátor, který ještě žádný student
     * v kolekci nemá.
     *
     * @param name jméno nového studenta
     * @return instanci třídy reprezentující nového studenta
     */
    Student newStudent(String name);
    
    /**
     * Vrátí kolekci všech studentů v katalogu. Kolekci není možné 
     * modifikovat.
     *
     * @return množinu všech studentů v katalogu
     */
    Collection<Student> getStudents();
    
    /**
     * Smaže všechny studenty v katalogu.
     */
    void clear();
    
}
